API - 语义数据库管理 — chat 1.0.3 documentation

# API - 语义数据库管理

Manage NLU database based on neo4j graph database. 管理基于neo4j图形数据库的自然语言理解数据库。

The ‘py2neo’ is a python package of neo4j graph database. 1.Support increase, delete, modify, query and other operations for nodes, relationships, subgraph and graph; 2.Support batch processing; 3.Support command line; 4.Support read the data file, batch import and export. “py2neo”是neo4j图形数据库的python接口包。 1.支持节点，关系，子图，全图的增、删、改、查； 2.支持批处理； 3.支持命令行； 4.支持读取数据文件批量导入及导出。

Available functions: - All classes and functions: 所有类和函数

`Database`([password, userid]) | Manage Database.

## 语义数据库管理

`chat.database.` `Database`(password=None, userid='userid')

  Manage Database. 管理数据库。

  It support python command line parameter processing of relational database and graph database. You can view all the features by ‘python xxx.py -h’. 支持关系数据库和图形数据库的python命令行参数处理。 可以通过’python xxx.py -h’查看所有功能。

  Public attributes: - rdb: Relational database. 关系数据库。 - graph: Graph database. 图数据库。